@@ -1,8 +1,9 @@
 #!/usr/bin/env python
-import airzone
-import sys
 import argparse
-from importlib_metadata import version, PackageNotFoundError
+
+from importlib_metadata import PackageNotFoundError, version  # type: ignore
+
+import airzone
 
 try:
     __version__ = version("python-airzone")
@@ -13,7 +14,10 @@ except PackageNotFoundError:
 
 def action(args):
     m = airzone.airzone_factory(args.serial, args.port, args.machine, args.system)
-    print(str(m))
+    if args.state == 'str':
+        print(str(m))
+    else:
+        print(str(m.get_machine_state()))
     
     
 parser = argparse.ArgumentParser(prog='airzone')
@@ -22,7 +26,8 @@ parser.add_argument("serial", type=str, help="serial device")
 parser.add_argument("port", type=str, help="serial tcp port")
 parser.add_argument("--machine", type=int, default=1, help="Machine number where connect")
 parser.add_argument("--system", choices = ['innobus', 'aido'], default = 'innobus', help="Type of Airzone System")
+parser.add_argument("--state", choices = ['str', 'raw'], default='str', help="Get the formatted state, or the raw machine state")
 parser.set_defaults(func=action)
 
 args = parser.parse_args()
-args.func(args)
\ No newline at end of file
+args.func(args)
